--[[
	Baggins_SectionColor

	adds colored frames around sections in baggins
	
	very useful for "all-in-one" display style with auto layout enabled
]]



-- hooks Baggins:CreateSectionFrame

Baggins_SectionColor = {}

Baggins_SectionColor.BagginsCreateSectionFrame = Baggins.CreateSectionFrame
Baggins_SectionColor.BagginsLayoutSection = Baggins.LayoutSection


function Baggins:CreateSectionFrame(bagframe,secid)
	local frame = Baggins_SectionColor.BagginsCreateSectionFrame(Baggins, bagframe, secid)

	local frameBorder = CreateFrame("Button", frame:GetName().."Border", frame)
	
	frameBorder:SetPoint("TOPLEFT", frame, "TOPLEFT", -6,6)
	frameBorder:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", 6,-6)
	
	frameBorder:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background", 
                                            edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
                                            tile = true, tileSize = 16, edgeSize = 16, 
                                            insets = { left = 4, right = 4, top = 4, bottom = 4 }})
	
	
	frameBorder:SetFrameLevel(frame.titleframe:GetFrameLevel()-1)
	
	
	frame.titleframe:SetScript("OnClick", function(this) if arg1=="LeftButton" then self:ToggleSection(this:GetParent()) else Baggins_SectionColor:SectionBorder_OnClick(this, arg1) end end)
	frame.titleframe:RegisterForClicks("LeftButtonDown","RightButtonDown")
	
	frameBorder:SetScript("OnClick", function() Baggins_SectionColor:SectionBorder_OnClick(this, arg1) end)
	frameBorder:RegisterForClicks("LeftButtonDown","RightButtonDown")
	
	frame.frameBorder = frameBorder
	return frame
end


function Baggins:LayoutSection(sectionframe, title, cols)
	Baggins_SectionColor.BagginsLayoutSection(Baggins, sectionframe, title, cols)
	
	local r,g,b,a = Baggins_SectionColor:GetDBSectionBackdropColor(sectionframe)
	
	sectionframe.frameBorder:SetBackdropColor(r,g,b,a)
	sectionframe.frameBorder:SetBackdropBorderColor(r,g,b,a*.75+.25)
end



function Baggins_SectionColor:GetDBSectionBackdropColor(sectionFrame)
	if sectionFrame then
		local bagName = sectionFrame:GetParent().title:GetName()
		local sectionName = sectionFrame.set_title
		
		local key = bagName .. ":" .. sectionName
		
		
		if not Baggins_SectionColorDB then
			Baggins_SectionColorDB = {}
		end
		
		if not Baggins_SectionColorDB.backdropColor then
			Baggins_SectionColorDB.backdropColor = {}
		end
		
		if not Baggins_SectionColorDB.backdropColor[key] then
			return 0,0,0,.4
		end
		
		local c = Baggins_SectionColorDB.backdropColor[key]

		return c.r, c.g, c.b, c.a
	end
	
	return 0,0,0,0
end



function Baggins_SectionColor:SetDBSectionBackdropColor(sectionFrame, r,g,b,a)
	if sectionFrame then
		local bagName = sectionFrame:GetParent().title:GetName()
		local sectionName = sectionFrame.set_title
		
		local key = bagName .. ":" .. sectionName
		
		
		if not Baggins_SectionColorDB then
			Baggins_SectionColorDB = {}
		end
		
		if not Baggins_SectionColorDB.backdropColor then
			Baggins_SectionColorDB.backdropColor = {}
		end
		
		if not Baggins_SectionColorDB.backdropColor[key] then
			Baggins_SectionColorDB.backdropColor[key] = {}
		end
		
		local c = Baggins_SectionColorDB.backdropColor[key]

		c.r, c.g, c.b, c.a = r,g,b,a
	end
end


	
local menuBorderFrame = {
	{
		text = "Change Backgdrop Color",
		func = function() Baggins_SectionColor:SelectBackdropColor(Baggins_SectionColor.selectedFrame) end,
	},
}


function Baggins_SectionColor:SectionBorder_OnClick(frame, mouse)
	if mouse == "RightButton" then
		local x, y = GetCursorPosition()
		local uiScale = UIParent:GetEffectiveScale()
		
		self.selectedFrame = frame:GetParent()
		
		if not Baggins_SectionColor_MenuFrame then
			Baggins_SectionColor_MenuFrame = CreateFrame("Frame", "BorderFrameMenu", getglobal("UIParent"), "UIDropDownMenuTemplate")
		end
		
		EasyMenu(menuBorderFrame, Baggins_SectionColor_MenuFrame, getglobal("UIParent"), x/uiScale,y/uiScale, "MENU", 5)
	end
end


function Baggins_SectionColor:SetBackdropColor(frame)
	local r,g,b = ColorPickerFrame:GetColorRGB()
	local alpha = 1-OpacitySliderFrame:GetValue()
	
	self:SetDBSectionBackdropColor(frame, r,g,b,alpha)
	frame.frameBorder:SetBackdropColor(r,g,b,alpha)
	frame.frameBorder:SetBackdropBorderColor(r,g,b,alpha*.75+.25)
end

function Baggins_SectionColor:RestoreBackdropColor(frame, previousValues)
	local r,g,b = previousValues.r, previousValues.g, previousValues.b
	local alpha = 1-previousValues.a
	
	self:SetDBSectionBackdropColor(frame, r,g,b,alpha)
	frame.frameBorder:SetBackdropColor(r,g,b,alpha)
	frame.frameBorder:SetBackdropBorderColor(r,g,b,alpha*.75+.25)
end



function Baggins_SectionColor:SelectBackdropColor(frame)
--DEFAULT_CHAT_FRAME:AddMessage("frame "..frame:GetName())
	ColorPickerFrame.func = function() Baggins_SectionColor:SetBackdropColor(frame) end
	ColorPickerFrame.opacityFunc = function() Baggins_SectionColor:SetBackdropColor(frame) end
	ColorPickerFrame.hasOpacity = true
	ColorPickerFrame.cancelFunc = function(previousValues) Baggins_SectionColor:RestoreBackdropColor(frame, previousValues) end
	
	local r,g,b,a = Baggins_SectionColor:GetDBSectionBackdropColor(frame)
	
	ColorPickerFrame.previousValues = {r=r,g=g,b=b,a=a}
	
	ColorPickerFrame:SetColorRGB(r,g,b)
	ColorPickerFrame.opacity = 1-a
	ColorPickerFrame:Show()
end
